SQL DDL — linkml documentation

# SQL DDL

## Overview

## Docs

### Command Line

#### gen-sqlddl

Generate SQL DDL representation

    gen-sqlddl [OPTIONS] YAMLFILE

Options

--dialect <dialect>

  SQL-Alchemy dialect, e.g. sqlite, mysql+odbc

--sqla-file <sqla_file>

  Path to sqlalchemy generated python

--python-import <python_import>

  Python import header for generated sql-alchemy code

--direct-mapping, --no-direct-mapping

  Map classes directly to

--use-foreign-keys, --no-use-foreign-keys

  Emit FK declarations

-f, --format <format>

  Output format (default=proto)

  Options

    proto

--metadata, --no-metadata

  Include metadata in output (default=–metadata)

--useuris, --metauris

  Include metadata in output (default=–useuris)

-im, --importmap <importmap>

  Import mapping file

--log_level <log_level>

  Logging level (default=WARNING)

  Options

    CRITICAL | ERROR | WARNING | INFO | DEBUG

--mergeimports, --no-mergeimports

  Merge imports into source file (default=mergeimports)

Arguments

YAMLFILE

  Required argument

### Code